/****************************************************************************
** Meta object code from reading C++ file 'kwalletd.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../src/kwallet-5.39.0/src/runtime/kwalletd/kwalletd.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kwalletd.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KWalletD_t {
    QByteArrayData data[79];
    char stringdata0[937];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KWalletD_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KWalletD_t qt_meta_stringdata_KWalletD = {
    {
QT_MOC_LITERAL(0, 0, 8), // "KWalletD"
QT_MOC_LITERAL(1, 9, 17), // "walletAsyncOpened"
QT_MOC_LITERAL(2, 27, 0), // ""
QT_MOC_LITERAL(3, 28, 2), // "id"
QT_MOC_LITERAL(4, 31, 6), // "handle"
QT_MOC_LITERAL(5, 38, 15), // "walletListDirty"
QT_MOC_LITERAL(6, 54, 13), // "walletCreated"
QT_MOC_LITERAL(7, 68, 6), // "wallet"
QT_MOC_LITERAL(8, 75, 12), // "walletOpened"
QT_MOC_LITERAL(9, 88, 13), // "walletDeleted"
QT_MOC_LITERAL(10, 102, 12), // "walletClosed"
QT_MOC_LITERAL(11, 115, 16), // "allWalletsClosed"
QT_MOC_LITERAL(12, 132, 17), // "folderListUpdated"
QT_MOC_LITERAL(13, 150, 13), // "folderUpdated"
QT_MOC_LITERAL(14, 164, 23), // "applicationDisconnected"
QT_MOC_LITERAL(15, 188, 11), // "application"
QT_MOC_LITERAL(16, 200, 9), // "isEnabled"
QT_MOC_LITERAL(17, 210, 4), // "open"
QT_MOC_LITERAL(18, 215, 3), // "wId"
QT_MOC_LITERAL(19, 219, 5), // "appid"
QT_MOC_LITERAL(20, 225, 8), // "openPath"
QT_MOC_LITERAL(21, 234, 4), // "path"
QT_MOC_LITERAL(22, 239, 9), // "openAsync"
QT_MOC_LITERAL(23, 249, 13), // "handleSession"
QT_MOC_LITERAL(24, 263, 13), // "openPathAsync"
QT_MOC_LITERAL(25, 277, 5), // "close"
QT_MOC_LITERAL(26, 283, 5), // "force"
QT_MOC_LITERAL(27, 289, 4), // "sync"
QT_MOC_LITERAL(28, 294, 9), // "Q_NOREPLY"
QT_MOC_LITERAL(29, 304, 12), // "deleteWallet"
QT_MOC_LITERAL(30, 317, 6), // "isOpen"
QT_MOC_LITERAL(31, 324, 5), // "users"
QT_MOC_LITERAL(32, 330, 14), // "changePassword"
QT_MOC_LITERAL(33, 345, 7), // "wallets"
QT_MOC_LITERAL(34, 353, 10), // "folderList"
QT_MOC_LITERAL(35, 364, 9), // "hasFolder"
QT_MOC_LITERAL(36, 374, 6), // "folder"
QT_MOC_LITERAL(37, 381, 12), // "createFolder"
QT_MOC_LITERAL(38, 394, 12), // "removeFolder"
QT_MOC_LITERAL(39, 407, 9), // "entryList"
QT_MOC_LITERAL(40, 417, 9), // "readEntry"
QT_MOC_LITERAL(41, 427, 3), // "key"
QT_MOC_LITERAL(42, 431, 7), // "readMap"
QT_MOC_LITERAL(43, 439, 12), // "readPassword"
QT_MOC_LITERAL(44, 452, 13), // "readEntryList"
QT_MOC_LITERAL(45, 466, 11), // "readMapList"
QT_MOC_LITERAL(46, 478, 16), // "readPasswordList"
QT_MOC_LITERAL(47, 495, 11), // "renameEntry"
QT_MOC_LITERAL(48, 507, 7), // "oldName"
QT_MOC_LITERAL(49, 515, 7), // "newName"
QT_MOC_LITERAL(50, 523, 10), // "writeEntry"
QT_MOC_LITERAL(51, 534, 5), // "value"
QT_MOC_LITERAL(52, 540, 9), // "entryType"
QT_MOC_LITERAL(53, 550, 8), // "writeMap"
QT_MOC_LITERAL(54, 559, 13), // "writePassword"
QT_MOC_LITERAL(55, 573, 8), // "hasEntry"
QT_MOC_LITERAL(56, 582, 11), // "removeEntry"
QT_MOC_LITERAL(57, 594, 21), // "disconnectApplication"
QT_MOC_LITERAL(58, 616, 11), // "reconfigure"
QT_MOC_LITERAL(59, 628, 18), // "folderDoesNotExist"
QT_MOC_LITERAL(60, 647, 15), // "keyDoesNotExist"
QT_MOC_LITERAL(61, 663, 15), // "closeAllWallets"
QT_MOC_LITERAL(62, 679, 13), // "networkWallet"
QT_MOC_LITERAL(63, 693, 11), // "localWallet"
QT_MOC_LITERAL(64, 705, 18), // "screenSaverChanged"
QT_MOC_LITERAL(65, 724, 7), // "pamOpen"
QT_MOC_LITERAL(66, 732, 12), // "passwordHash"
QT_MOC_LITERAL(67, 745, 14), // "sessionTimeout"
QT_MOC_LITERAL(68, 760, 23), // "slotServiceOwnerChanged"
QT_MOC_LITERAL(69, 784, 4), // "name"
QT_MOC_LITERAL(70, 789, 8), // "oldOwner"
QT_MOC_LITERAL(71, 798, 8), // "newOwner"
QT_MOC_LITERAL(72, 807, 19), // "emitWalletListDirty"
QT_MOC_LITERAL(73, 827, 13), // "timedOutClose"
QT_MOC_LITERAL(74, 841, 12), // "timedOutSync"
QT_MOC_LITERAL(75, 854, 14), // "notifyFailures"
QT_MOC_LITERAL(76, 869, 19), // "processTransactions"
QT_MOC_LITERAL(77, 889, 22), // "activatePasswordDialog"
QT_MOC_LITERAL(78, 912, 24) // "registerKWalletd4Service"

    },
    "KWalletD\0walletAsyncOpened\0\0id\0handle\0"
    "walletListDirty\0walletCreated\0wallet\0"
    "walletOpened\0walletDeleted\0walletClosed\0"
    "allWalletsClosed\0folderListUpdated\0"
    "folderUpdated\0applicationDisconnected\0"
    "application\0isEnabled\0open\0wId\0appid\0"
    "openPath\0path\0openAsync\0handleSession\0"
    "openPathAsync\0close\0force\0sync\0Q_NOREPLY\0"
    "deleteWallet\0isOpen\0users\0changePassword\0"
    "wallets\0folderList\0hasFolder\0folder\0"
    "createFolder\0removeFolder\0entryList\0"
    "readEntry\0key\0readMap\0readPassword\0"
    "readEntryList\0readMapList\0readPasswordList\0"
    "renameEntry\0oldName\0newName\0writeEntry\0"
    "value\0entryType\0writeMap\0writePassword\0"
    "hasEntry\0removeEntry\0disconnectApplication\0"
    "reconfigure\0folderDoesNotExist\0"
    "keyDoesNotExist\0closeAllWallets\0"
    "networkWallet\0localWallet\0screenSaverChanged\0"
    "pamOpen\0passwordHash\0sessionTimeout\0"
    "slotServiceOwnerChanged\0name\0oldOwner\0"
    "newOwner\0emitWalletListDirty\0timedOutClose\0"
    "timedOutSync\0notifyFailures\0"
    "processTransactions\0activatePasswordDialog\0"
    "registerKWalletd4Service"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KWalletD[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      61,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      11,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,  319,    2, 0x06 /* Public */,
       5,    0,  324,    2, 0x06 /* Public */,
       6,    1,  325,    2, 0x06 /* Public */,
       8,    1,  328,    2, 0x06 /* Public */,
       9,    1,  331,    2, 0x06 /* Public */,
      10,    1,  334,    2, 0x06 /* Public */,
      10,    1,  337,    2, 0x06 /* Public */,
      11,    0,  340,    2, 0x06 /* Public */,
      12,    1,  341,    2, 0x06 /* Public */,
      13,    2,  344,    2, 0x06 /* Public */,
      14,    2,  349,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      16,    0,  354,    2, 0x0a /* Public */,
      17,    3,  355,    2, 0x0a /* Public */,
      20,    3,  362,    2, 0x0a /* Public */,
      22,    4,  369,    2, 0x0a /* Public */,
      24,    4,  378,    2, 0x0a /* Public */,
      25,    2,  387,    2, 0x0a /* Public */,
      25,    3,  392,    2, 0x0a /* Public */,
      27,    2,  399,   28, 0x0a /* Public */,
      29,    1,  404,    2, 0x0a /* Public */,
      30,    1,  407,    2, 0x0a /* Public */,
      30,    1,  410,    2, 0x0a /* Public */,
      31,    1,  413,    2, 0x0a /* Public */,
      32,    3,  416,    2, 0x0a /* Public */,
      33,    0,  423,    2, 0x0a /* Public */,
      34,    2,  424,    2, 0x0a /* Public */,
      35,    3,  429,    2, 0x0a /* Public */,
      37,    3,  436,    2, 0x0a /* Public */,
      38,    3,  443,    2, 0x0a /* Public */,
      39,    3,  450,    2, 0x0a /* Public */,
      40,    4,  457,    2, 0x0a /* Public */,
      42,    4,  466,    2, 0x0a /* Public */,
      43,    4,  475,    2, 0x0a /* Public */,
      44,    4,  484,    2, 0x0a /* Public */,
      45,    4,  493,    2, 0x0a /* Public */,
      46,    4,  502,    2, 0x0a /* Public */,
      47,    5,  511,    2, 0x0a /* Public */,
      50,    6,  522,    2, 0x0a /* Public */,
      50,    5,  535,    2, 0x0a /* Public */,
      53,    5,  546,    2, 0x0a /* Public */,
      54,    5,  557,    2, 0x0a /* Public */,
      55,    4,  568,    2, 0x0a /* Public */,
      52,    4,  577,    2, 0x0a /* Public */,
      56,    4,  586,    2, 0x0a /* Public */,
      57,    2,  595,    2, 0x0a /* Public */,
      58,    0,  600,    2, 0x0a /* Public */,
      59,    2,  601,    2, 0x0a /* Public */,
      60,    3,  606,    2, 0x0a /* Public */,
      61,    0,  613,    2, 0x0a /* Public */,
      62,    0,  614,    2, 0x0a /* Public */,
      63,    0,  615,    2, 0x0a /* Public */,
      64,    1,  616,    2, 0x0a /* Public */,
      65,    3,  619,    2, 0x0a /* Public */,
      68,    3,  626,    2, 0x08 /* Private */,
      72,    0,  633,    2, 0x08 /* Private */,
      73,    1,  634,    2, 0x08 /* Private */,
      74,    1,  637,    2, 0x08 /* Private */,
      75,    0,  640,    2, 0x08 /* Private */,
      76,    0,  641,    2, 0x08 /* Private */,
      77,    0,  642,    2, 0x08 /* Private */,
      78,    0,  643,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::Int, QMetaType::Int,    3,    4,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    7,
    QMetaType::Void, QMetaType::QString,    7,
    QMetaType::Void, QMetaType::QString,    7,
    QMetaType::Void, QMetaType::QString,    7,
    QMetaType::Void, QMetaType::Int,    4,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    7,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,    2,    2,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,    7,   15,

 // slots: parameters
    QMetaType::Bool,
    QMetaType::Int, QMetaType::QString, QMetaType::LongLong, QMetaType::QString,    7,   18,   19,
    QMetaType::Int, QMetaType::QString, QMetaType::LongLong, QMetaType::QString,   21,   18,   19,
    QMetaType::Int, QMetaType::QString, QMetaType::LongLong, QMetaType::QString, QMetaType::Bool,    7,   18,   19,   23,
    QMetaType::Int, QMetaType::QString, QMetaType::LongLong, QMetaType::QString, QMetaType::Bool,   21,   18,   19,   23,
    QMetaType::Int, QMetaType::QString, QMetaType::Bool,    7,   26,
    QMetaType::Int, QMetaType::Int, QMetaType::Bool, QMetaType::QString,    4,   26,   19,
    QMetaType::Void, QMetaType::Int, QMetaType::QString,    4,   19,
    QMetaType::Int, QMetaType::QString,    7,
    QMetaType::Bool, QMetaType::QString,    7,
    QMetaType::Bool, QMetaType::Int,    4,
    QMetaType::QStringList, QMetaType::QString,    7,
    QMetaType::Void, QMetaType::QString, QMetaType::LongLong, QMetaType::QString,    7,   18,   19,
    QMetaType::QStringList,
    QMetaType::QStringList, QMetaType::Int, QMetaType::QString,    4,   19,
    QMetaType::Bool, QMetaType::Int, QMetaType::QString, QMetaType::QString,    4,   36,   19,
    QMetaType::Bool, QMetaType::Int, QMetaType::QString, QMetaType::QString,    4,   36,   19,
    QMetaType::Bool, QMetaType::Int, QMetaType::QString, QMetaType::QString,    4,   36,   19,
    QMetaType::QStringList, QMetaType::Int, QMetaType::QString, QMetaType::QString,    4,   36,   19,
    QMetaType::QByteArray, QMetaType::Int, QMetaType::QString, QMetaType::QString, QMetaType::QString,    4,   36,   41,   19,
    QMetaType::QByteArray, QMetaType::Int, QMetaType::QString, QMetaType::QString, QMetaType::QString,    4,   36,   41,   19,
    QMetaType::QString, QMetaType::Int, QMetaType::QString, QMetaType::QString, QMetaType::QString,    4,   36,   41,   19,
    QMetaType::QVariantMap, QMetaType::Int, QMetaType::QString, QMetaType::QString, QMetaType::QString,    4,   36,   41,   19,
    QMetaType::QVariantMap, QMetaType::Int, QMetaType::QString, QMetaType::QString, QMetaType::QString,    4,   36,   41,   19,
    QMetaType::QVariantMap, QMetaType::Int, QMetaType::QString, QMetaType::QString, QMetaType::QString,    4,   36,   41,   19,
    QMetaType::Int, QMetaType::Int, QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::QString,    4,   36,   48,   49,   19,
    QMetaType::Int, QMetaType::Int, QMetaType::QString, QMetaType::QString, QMetaType::QByteArray, QMetaType::Int, QMetaType::QString,    4,   36,   41,   51,   52,   19,
    QMetaType::Int, QMetaType::Int, QMetaType::QString, QMetaType::QString, QMetaType::QByteArray, QMetaType::QString,    4,   36,   41,   51,   19,
    QMetaType::Int, QMetaType::Int, QMetaType::QString, QMetaType::QString, QMetaType::QByteArray, QMetaType::QString,    4,   36,   41,   51,   19,
    QMetaType::Int, QMetaType::Int, QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::QString,    4,   36,   41,   51,   19,
    QMetaType::Bool, QMetaType::Int, QMetaType::QString, QMetaType::QString, QMetaType::QString,    4,   36,   41,   19,
    QMetaType::Int, QMetaType::Int, QMetaType::QString, QMetaType::QString, QMetaType::QString,    4,   36,   41,   19,
    QMetaType::Int, QMetaType::Int, QMetaType::QString, QMetaType::QString, QMetaType::QString,    4,   36,   41,   19,
    QMetaType::Bool, QMetaType::QString, QMetaType::QString,    7,   15,
    QMetaType::Void,
    QMetaType::Bool, QMetaType::QString, QMetaType::QString,    7,   36,
    QMetaType::Bool, QMetaType::QString, QMetaType::QString, QMetaType::QString,    7,   36,   41,
    QMetaType::Void,
    QMetaType::QString,
    QMetaType::QString,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Int, QMetaType::QString, QMetaType::QByteArray, QMetaType::Int,    7,   66,   67,
    QMetaType::Void, QMetaType::QString, QMetaType::QString, QMetaType::QString,   69,   70,   71,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    4,
    QMetaType::Void, QMetaType::Int,    4,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void KWalletD::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KWalletD *_t = static_cast<KWalletD *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->walletAsyncOpened((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 1: _t->walletListDirty(); break;
        case 2: _t->walletCreated((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 3: _t->walletOpened((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 4: _t->walletDeleted((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 5: _t->walletClosed((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 6: _t->walletClosed((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 7: _t->allWalletsClosed(); break;
        case 8: _t->folderListUpdated((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 9: _t->folderUpdated((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 10: _t->applicationDisconnected((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 11: { bool _r = _t->isEnabled();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 12: { int _r = _t->open((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< qlonglong(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 13: { int _r = _t->openPath((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< qlonglong(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 14: { int _r = _t->openAsync((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< qlonglong(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< bool(*)>(_a[4])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 15: { int _r = _t->openPathAsync((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< qlonglong(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< bool(*)>(_a[4])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 16: { int _r = _t->close((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 17: { int _r = _t->close((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 18: _t->sync((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 19: { int _r = _t->deleteWallet((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 20: { bool _r = _t->isOpen((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 21: { bool _r = _t->isOpen((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 22: { QStringList _r = _t->users((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QStringList*>(_a[0]) = std::move(_r); }  break;
        case 23: _t->changePassword((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< qlonglong(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 24: { QStringList _r = _t->wallets();
            if (_a[0]) *reinterpret_cast< QStringList*>(_a[0]) = std::move(_r); }  break;
        case 25: { QStringList _r = _t->folderList((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QStringList*>(_a[0]) = std::move(_r); }  break;
        case 26: { bool _r = _t->hasFolder((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 27: { bool _r = _t->createFolder((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 28: { bool _r = _t->removeFolder((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 29: { QStringList _r = _t->entryList((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< QStringList*>(_a[0]) = std::move(_r); }  break;
        case 30: { QByteArray _r = _t->readEntry((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4])));
            if (_a[0]) *reinterpret_cast< QByteArray*>(_a[0]) = std::move(_r); }  break;
        case 31: { QByteArray _r = _t->readMap((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4])));
            if (_a[0]) *reinterpret_cast< QByteArray*>(_a[0]) = std::move(_r); }  break;
        case 32: { QString _r = _t->readPassword((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 33: { QVariantMap _r = _t->readEntryList((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4])));
            if (_a[0]) *reinterpret_cast< QVariantMap*>(_a[0]) = std::move(_r); }  break;
        case 34: { QVariantMap _r = _t->readMapList((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4])));
            if (_a[0]) *reinterpret_cast< QVariantMap*>(_a[0]) = std::move(_r); }  break;
        case 35: { QVariantMap _r = _t->readPasswordList((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4])));
            if (_a[0]) *reinterpret_cast< QVariantMap*>(_a[0]) = std::move(_r); }  break;
        case 36: { int _r = _t->renameEntry((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4])),(*reinterpret_cast< const QString(*)>(_a[5])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 37: { int _r = _t->writeEntry((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< const QByteArray(*)>(_a[4])),(*reinterpret_cast< int(*)>(_a[5])),(*reinterpret_cast< const QString(*)>(_a[6])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 38: { int _r = _t->writeEntry((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< const QByteArray(*)>(_a[4])),(*reinterpret_cast< const QString(*)>(_a[5])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 39: { int _r = _t->writeMap((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< const QByteArray(*)>(_a[4])),(*reinterpret_cast< const QString(*)>(_a[5])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 40: { int _r = _t->writePassword((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4])),(*reinterpret_cast< const QString(*)>(_a[5])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 41: { bool _r = _t->hasEntry((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 42: { int _r = _t->entryType((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 43: { int _r = _t->removeEntry((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 44: { bool _r = _t->disconnectApplication((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 45: _t->reconfigure(); break;
        case 46: { bool _r = _t->folderDoesNotExist((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 47: { bool _r = _t->keyDoesNotExist((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 48: _t->closeAllWallets(); break;
        case 49: { QString _r = _t->networkWallet();
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 50: { QString _r = _t->localWallet();
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 51: _t->screenSaverChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 52: { int _r = _t->pamOpen((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QByteArray(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 53: _t->slotServiceOwnerChanged((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 54: _t->emitWalletListDirty(); break;
        case 55: _t->timedOutClose((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 56: _t->timedOutSync((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 57: _t->notifyFailures(); break;
        case 58: _t->processTransactions(); break;
        case 59: _t->activatePasswordDialog(); break;
        case 60: _t->registerKWalletd4Service(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (KWalletD::*_t)(int , int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KWalletD::walletAsyncOpened)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (KWalletD::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KWalletD::walletListDirty)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (KWalletD::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KWalletD::walletCreated)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (KWalletD::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KWalletD::walletOpened)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (KWalletD::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KWalletD::walletDeleted)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (KWalletD::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KWalletD::walletClosed)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (KWalletD::*_t)(int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KWalletD::walletClosed)) {
                *result = 6;
                return;
            }
        }
        {
            typedef void (KWalletD::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KWalletD::allWalletsClosed)) {
                *result = 7;
                return;
            }
        }
        {
            typedef void (KWalletD::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KWalletD::folderListUpdated)) {
                *result = 8;
                return;
            }
        }
        {
            typedef void (KWalletD::*_t)(const QString & , const QString & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KWalletD::folderUpdated)) {
                *result = 9;
                return;
            }
        }
        {
            typedef void (KWalletD::*_t)(const QString & , const QString & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KWalletD::applicationDisconnected)) {
                *result = 10;
                return;
            }
        }
    }
}

const QMetaObject KWalletD::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_KWalletD.data,
      qt_meta_data_KWalletD,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KWalletD::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KWalletD::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KWalletD.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QDBusContext"))
        return static_cast< QDBusContext*>(this);
    return QObject::qt_metacast(_clname);
}

int KWalletD::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 61)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 61;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 61)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 61;
    }
    return _id;
}

// SIGNAL 0
void KWalletD::walletAsyncOpened(int _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void KWalletD::walletListDirty()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KWalletD::walletCreated(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void KWalletD::walletOpened(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void KWalletD::walletDeleted(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void KWalletD::walletClosed(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void KWalletD::walletClosed(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void KWalletD::allWalletsClosed()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void KWalletD::folderListUpdated(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}

// SIGNAL 9
void KWalletD::folderUpdated(const QString & _t1, const QString & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 9, _a);
}

// SIGNAL 10
void KWalletD::applicationDisconnected(const QString & _t1, const QString & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 10, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
